@@ -1,18 +1,6 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2019.2
-# Email : muyanru345@163.com
-###################################################################
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtWidgets
+from qtpy import QtCore
+from qtpy import QtWidgets
 
 # Import local modules
 from dayu_widgets import dayu_theme
@@ -44,9 +32,7 @@ class MComboBoxSearchMixin(object):
         edit.setReadOnly(False)
         edit.returnPressed.disconnect()
         edit.textEdited.connect(self.filter_model.setFilterFixedString)
-        self.completer.activated.connect(
-            lambda t: t and self.setCurrentIndex(self.findText(t))
-        )
+        self.completer.activated.connect(lambda t: t and self.setCurrentIndex(self.findText(t)))
 
     def _set_searchable(self, value):
         """search property to True then trigger search"""
@@ -84,9 +70,7 @@ class MComboBox(MComboBoxSearchMixin, QtWidgets.QComboBox):
         self._has_custom_view = False
         self.set_value("")
         self.set_placeholder(self.tr("Please Select"))
-        self.setSizePolicy(
-            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
-        )
+        self.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
         self._dayu_size = dayu_theme.default_size
         dayu_theme.apply(self)
 
@@ -146,7 +130,7 @@ class MComboBox(MComboBoxSearchMixin, QtWidgets.QComboBox):
     #     raise NotImplementedError
 
     def eventFilter(self, widget, event):
-        if widget is self.lineEdit() and widget.isReadOnly():
+        if widget is self.lineEdit() and widget.isReadOnly() and self.isEnabled():
             if event.type() == QtCore.QEvent.MouseButtonPress:
                 self.showPopup()
         return super(MComboBox, self).eventFilter(widget, event)
