@@ -1,19 +1,7 @@
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2019.3
-# Email : muyanru345@163.com
-###################################################################
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtGui
-from Qt import QtWidgets
-import six
+from qtpy import QtCore
+from qtpy import QtGui
+from qtpy import QtWidgets
 
 # Import local modules
 from dayu_widgets import dayu_theme
@@ -29,9 +17,6 @@ HEADER_SORT_MAP = {"asc": QtCore.Qt.AscendingOrder, "desc": QtCore.Qt.Descending
 
 
 def draw_empty_content(view, text=None, pix_map=None):
-    # Import local modules
-    from dayu_widgets import dayu_theme
-
     pix_map = pix_map or MPixmap("empty.svg")
     text = text or view.tr("No Data")
     painter = QtGui.QPainter(view)
@@ -40,12 +25,13 @@ def draw_empty_content(view, text=None, pix_map=None):
     content_height = pix_map.height() + font_metrics.height()
     padding = 10
     proper_min_size = min(
-        view.height() - padding * 2, view.width() - padding * 2, content_height
+        view.height() - padding * 2,
+        view.width() - padding * 2,
+        content_height
     )
     if proper_min_size < content_height:
-        pix_map = pix_map.scaledToHeight(
-            proper_min_size - font_metrics.height(), QtCore.Qt.SmoothTransformation
-        )
+        height = proper_min_size - font_metrics.height()
+        pix_map = pix_map.scaledToHeight(height, QtCore.Qt.SmoothTransformation)
         content_height = proper_min_size
     painter.drawText(
         view.width() / 2 - font_metrics.width(text) / 2,
@@ -93,11 +79,8 @@ class MOptionDelegate(QtWidgets.QStyledItemDelegate):
         model.setData(index, editor.property("value"))
 
     def updateEditorGeometry(self, editor, option, index):
-        editor.move(
-            self.parent_widget.mapToGlobal(
-                QtCore.QPoint(option.rect.x(), option.rect.y() + option.rect.height())
-            )
-        )
+        point = QtCore.QPoint(option.rect.x(), option.rect.y() + option.rect.height())
+        editor.move(self.parent_widget.mapToGlobal(point))
 
     def paint(self, painter, option, index):
         painter.save()
@@ -114,9 +97,7 @@ class MOptionDelegate(QtWidgets.QStyledItemDelegate):
         pix = MPixmap("down_fill.svg", icon_color)
         h = option.rect.height()
         pix = pix.scaledToWidth(h * 0.5, QtCore.Qt.SmoothTransformation)
-        painter.drawPixmap(
-            option.rect.x() + option.rect.width() - h, option.rect.y() + h / 4, pix
-        )
+        painter.drawPixmap(option.rect.x() + option.rect.width() - h, option.rect.y() + h / 4, pix)
         painter.restore()
         super(MOptionDelegate, self).paint(painter, option, index)
 
@@ -169,15 +150,16 @@ def slot_context_menu(self, point):
     if proxy_index.isValid():
         need_map = isinstance(self.model(), QtCore.QSortFilterProxyModel)
         selection = []
-        for index in (
+        selected = (
             self.selectionModel().selectedRows()
             or self.selectionModel().selectedIndexes()
-        ):
-            data_obj = (
-                self.model().mapToSource(index).internalPointer()
-                if need_map
-                else index.internalPointer()
-            )
+        )
+        for index in selected:
+            if need_map:
+                source_index = self.model().mapToSource(index)
+                data_obj = source_index.internalPointer()
+            else:
+                data_obj = index.internalPointer()
             selection.append(data_obj)
         event = utils.ItemViewMenuEvent(view=self, selection=selection, extra={})
         self.sig_context_menu.emit(event)
@@ -212,7 +194,7 @@ def mouse_release_event(self, event):
         if value:
             if isinstance(value, dict):
                 self.sig_link_clicked.emit(value)
-            elif isinstance(value, six.string_types):
+            elif isinstance(value, str):
                 self.sig_link_clicked.emit(data_obj)
             elif isinstance(value, list):
                 for i in value:
@@ -230,8 +212,9 @@ class MTableView(QtWidgets.QTableView):
         self._no_data_image = None
         self._no_data_text = self.tr("No Data")
         size = size or dayu_theme.default_size
-        ver_header_view = MHeaderView(QtCore.Qt.Vertical, parent=self)
+        ver_header_view = MHeaderView(QtCore.Qt.Vertical, parent=self, show_sort_indicator=False)
         ver_header_view.setDefaultSectionSize(size)
+        ver_header_view.setSortIndicatorShown(False)
         self.setVerticalHeader(ver_header_view)
         self.header_list = []
         self.header_view = MHeaderView(QtCore.Qt.Horizontal, parent=self)
@@ -288,9 +271,7 @@ class MTableView(QtWidgets.QTableView):
             draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         elif isinstance(model, MTableModel):
             if not model.get_data_list():
-                draw_empty_content(
-                    self.viewport(), self._no_data_text, self._no_data_image
-                )
+                draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         return super(MTableView, self).paintEvent(event)
 
     def save_state(self, name):
@@ -298,19 +279,19 @@ class MTableView(QtWidgets.QTableView):
             QtCore.QSettings.IniFormat,
             QtCore.QSettings.UserScope,
             "DAYU",
-            "dayu_widgets",
+            "dayu_widgets3",
         )
-        settings.setValue("{}/headerState".format(name, self.header_view.saveState()))
+        settings.setValue(f"{name}/headerState", self.header_view.saveState())
 
     def load_state(self, name):
         settings = QtCore.QSettings(
             QtCore.QSettings.IniFormat,
             QtCore.QSettings.UserScope,
             "DAYU",
-            "dayu_widgets",
+            "dayu_widgets3",
         )
-        if settings.value("{}/headerState".format(name)):
-            self.header_view.restoreState(settings.value("{}/headerState".format(name)))
+        if settings.value(f"{name}/headerState"):
+            self.header_view.restoreState(settings.value(f"{name}/headerState"))
 
 
 class MTreeView(QtWidgets.QTreeView):
@@ -336,9 +317,7 @@ class MTreeView(QtWidgets.QTreeView):
             draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         elif isinstance(model, MTableModel):
             if not model.get_data_list():
-                draw_empty_content(
-                    self.viewport(), self._no_data_text, self._no_data_image
-                )
+                draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         return super(MTreeView, self).paintEvent(event)
 
     def set_no_data_text(self, text):
@@ -361,7 +340,19 @@ class MBigView(QtWidgets.QListView):
         self.setResizeMode(QtWidgets.QListView.Adjust)
         self.setMovement(QtWidgets.QListView.Static)
         self.setSpacing(10)
-        self.setIconSize(QtCore.QSize(128, 128))
+        default_size = dayu_theme.big_view_default_size
+        self.setIconSize(QtCore.QSize(default_size, default_size))
+
+    def scale_size(self, factor):
+        """Scale the icon size."""
+        new_size = self.iconSize() * factor
+        max_size = dayu_theme.big_view_max_size
+        min_size = dayu_theme.big_view_min_size
+        if new_size.width() > max_size:
+            new_size = QtCore.QSize(max_size, max_size)
+        elif new_size.width() < min_size:
+            new_size = QtCore.QSize(min_size, min_size)
+        self.setIconSize(new_size)
 
     def wheelEvent(self, event):
         """Override wheelEvent while user press ctrl, zoom the list view icon size."""
@@ -369,12 +360,7 @@ class MBigView(QtWidgets.QListView):
             num_degrees = event.delta() / 8.0
             num_steps = num_degrees / 15.0
             factor = pow(1.125, num_steps)
-            new_size = self.iconSize() * factor
-            if new_size.width() > 200:
-                new_size = QtCore.QSize(200, 200)
-            elif new_size.width() < 24:
-                new_size = QtCore.QSize(24, 24)
-            self.setIconSize(new_size)
+            self.scale_size(factor)
         else:
             super(MBigView, self).wheelEvent(event)
 
@@ -385,9 +371,7 @@ class MBigView(QtWidgets.QListView):
             draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         elif isinstance(model, MTableModel):
             if not model.get_data_list():
-                draw_empty_content(
-                    self.viewport(), self._no_data_text, self._no_data_image
-                )
+                draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         return super(MBigView, self).paintEvent(event)
 
     def set_no_data_text(self, text):
@@ -425,9 +409,7 @@ class MListView(QtWidgets.QListView):
             draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         elif isinstance(model, MTableModel):
             if not model.get_data_list():
-                draw_empty_content(
-                    self.viewport(), self._no_data_text, self._no_data_image
-                )
+                draw_empty_content(self.viewport(), self._no_data_text, self._no_data_image)
         return super(MListView, self).paintEvent(event)
 
     def set_no_data_text(self, text):
