@@ -1,22 +1,9 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: TimmyLiang
-# Date  : 2021.12
-# Email : 820472580@qq.com
-###################################################################
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Import built-in modules
 from functools import partial
 
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtGui
-from Qt import QtWidgets
+from qtpy import QtCore
+from qtpy import QtWidgets
 
 # Import local modules
 from dayu_widgets import dayu_theme
@@ -46,7 +33,6 @@ class MSplitter(QtWidgets.QSplitter):
             size_list[index] = default_size
             size_list[prev] -= default_size
         else:
-
             if first:
                 size_list[index] += prev_size
                 size_list[prev] = 0
@@ -78,9 +64,7 @@ class MSplitter(QtWidgets.QSplitter):
         handle = QtWidgets.QSplitterHandle(orient, self)
 
         # NOTES: double click average size
-        handle.mouseDoubleClickEvent = lambda e: self.setSizes(
-            [1 for i in range(self.count())]
-        )
+        handle.mouseDoubleClickEvent = lambda e: self.setSizes([1 for i in range(self.count())])
 
         layout = QtWidgets.QVBoxLayout() if is_horizontal else QtWidgets.QHBoxLayout()
         layout.setContentsMargins(0, 0, 0, 0)
