@@ -1,15 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2019.2
-# Email : muyanru345@163.com
-###################################################################
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Import built-in modules
 import string
 
@@ -78,17 +66,26 @@ def get_theme_size():
         "check_box_size": int(13 * scale_factor_x),
         "check_box_spacing": int(4 * scale_factor_x),
         "radio_size": int(14 * scale_factor_x),
-        "radio_radius": int(14 * scale_factor_x) / 2.0,
+        "radio_radius": int(14 * scale_factor_x / 2.0),
         "radio_spacing": int(4 * scale_factor_x),
         "slider_height": int(4 * scale_factor_x),
         "slider_radius": int(3 * scale_factor_x),
         "slider_handle_size": int(8 * scale_factor_x),
-        "slider_handle_radius": int(8 * scale_factor_x) / 1.5,
+        "slider_handle_radius": int(8 * scale_factor_x / 1.5),
         "progress_circle_default_radius": int(120 * scale_factor_x),
         "progress_bar_size": int(12 * scale_factor_x),
-        "progress_bar_radius": int(12 * scale_factor_x) / 2.0,
+        "progress_bar_radius": int(12 * scale_factor_x / 2.0),
         "toast_size": int(120 * scale_factor_x),
         "toast_icon_size": int(60 * scale_factor_x),
+        "big_view_default_size": int(120 * scale_factor_x),
+        "big_view_max_size": int(400 * scale_factor_x),
+        "big_view_min_size": int(24 * scale_factor_x),
+        "indicator_padding": int(4 * scale_factor_x),
+        "indicator_size": int(8 * scale_factor_x),
+        "scroll_bar_size": int(12 * scale_factor_x),
+        "scroll_bar_min_length": int(20 * scale_factor_x),
+        "scroll_bar_margin": int(12 * scale_factor_x * 2) + 1,
+        "scroll_bar_radius": int(12 * scale_factor_x / 2.0),
     }
 
 
