@@ -1,36 +1,18 @@
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2018.5
-# Email : muyanru345@163.com
-###################################################################
 """
 Some helper functions for handling color and formatter.
 """
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 # Import built-in modules
 import collections
 import datetime as dt
-import functools
+from functools import singledispatch
 import math
 import os
 
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtGui
-from Qt import QtWidgets
-import six
-
-
-if hasattr(functools, "singledispatch"):
-    # Import built-in modules
-    from functools import singledispatch
-else:
-    from singledispatch import singledispatch
+from qtpy import QtCore
+from qtpy import QtGui
+from qtpy import QtWidgets
 
 # Import local modules
 from dayu_widgets import CUSTOM_STATIC_FOLDERS
@@ -39,9 +21,7 @@ from dayu_widgets.qt import MIcon
 from dayu_widgets.qt import get_scale_factor
 
 
-ItemViewMenuEvent = collections.namedtuple(
-    "ItemViewMenuEvent", ["view", "selection", "extra"]
-)
+ItemViewMenuEvent = collections.namedtuple("ItemViewMenuEvent", ["view", "selection", "extra"])
 
 
 def get_static_file(path):
@@ -52,11 +32,8 @@ def get_static_file(path):
     :param path: file name
     :return: if input file found, return the full path, else return None
     """
-    if not isinstance(path, six.string_types):
-        raise TypeError(
-            "Input argument 'path' should be six.string_types type, "
-            "but get {}".format(type(path))
-        )
+    if not isinstance(path, str):
+        raise TypeError("Input argument 'path' should be str type, " "but get {}".format(type(path)))
     full_path = next(
         (
             os.path.join(prefix, path)
@@ -78,15 +55,9 @@ def from_list_to_nested_dict(input_arg, sep="/"):
     :return: a list of nested dict
     """
     if not isinstance(input_arg, (list, tuple, set)):
-        raise TypeError(
-            "Input argument 'input' should be list or tuple or set, "
-            "but get {}".format(type(input_arg))
-        )
-    if not isinstance(sep, six.string_types):
-        raise TypeError(
-            "Input argument 'sep' should be six.string_types, "
-            "but get {}".format(type(sep))
-        )
+        raise TypeError("Input argument 'input' should be list or tuple or set, " "but get {}".format(type(input_arg)))
+    if not isinstance(sep, str):
+        raise TypeError("Input argument 'sep' should be str, " "but get {}".format(type(sep)))
 
     result = []
     for item in input_arg:
@@ -113,9 +84,7 @@ def fade_color(color, alpha):
     :return: qss/css color format rgba(r, g, b, a)
     """
     q_color = QtGui.QColor(color)
-    return "rgba({}, {}, {}, {})".format(
-        q_color.red(), q_color.green(), q_color.blue(), alpha
-    )
+    return "rgba({}, {}, {}, {})".format(q_color.red(), q_color.green(), q_color.blue(), alpha)
 
 
 def generate_color(primary_color, index):
@@ -170,11 +139,7 @@ def generate_color(primary_color, index):
         return max((v_comp * 100 - brightness_step2 * i) / 100, 0.0)
 
     light = index <= 6
-    hsv_color = (
-        QtGui.QColor(primary_color)
-        if isinstance(primary_color, six.string_types)
-        else primary_color
-    )
+    hsv_color = QtGui.QColor(primary_color) if isinstance(primary_color, str) else primary_color
     index = light_color_count + 1 - index if light else index - light_color_count - 1
     return QtGui.QColor.fromHsvF(
         _get_hue(hsv_color, index, light),
@@ -257,7 +222,7 @@ def display_formatter(input_other_type):
     Used for QAbstractItemModel data method for Qt.DisplayRole
     Format any input value to a string.
     :param input_other_type: any type value
-    :return: six.string_types
+    :return: str
     """
     return str(input_other_type)  # this function never reached
 
@@ -286,7 +251,7 @@ def _(input_str):
     # return obj.decode()
 
 
-@display_formatter.register(six.text_type)
+@display_formatter.register(str)
 def _(input_unicode):
     return input_unicode
 
@@ -387,14 +352,9 @@ def overflow_format(num, overflow):
     When this integer is large than given overflow, return "overflow+"
     """
     if not isinstance(num, int):
-        raise ValueError(
-            "Input argument 'num' should be int type, " "but get {}".format(type(num))
-        )
+        raise ValueError("Input argument 'num' should be int type, " "but get {}".format(type(num)))
     if not isinstance(overflow, int):
-        raise ValueError(
-            "Input argument 'overflow' should be int type, "
-            "but get {}".format(type(overflow))
-        )
+        raise ValueError("Input argument 'overflow' should be int type, " "but get {}".format(type(overflow)))
     return str(num) if num <= overflow else "{}+".format(overflow)
 
 
@@ -450,13 +410,21 @@ def read_settings(organization, app_name):
     result_dict = {key: settings.value(key) for key in settings.childKeys()}
     for grp_name in settings.childGroups():
         settings.beginGroup(grp_name)
-        result_dict.update(
-            {grp_name + "/" + key: settings.value(key) for key in settings.childKeys()}
-        )
+        result_dict.update({grp_name + "/" + key: settings.value(key) for key in settings.childKeys()})
         settings.endGroup()
     return result_dict
 
 
+def is_qt_object_alive(obj):
+    try:
+        # 尝试访问对象的某个基本属性
+        # 如果对象已被删除，这将引发异常
+        obj.objectName()
+        return True
+    except (RuntimeError, ReferenceError):
+        return False
+
+
 def add_settings(organization, app_name, event_name="closeEvent"):
     def _write_settings(self):
         settings = QtCore.QSettings(
@@ -466,6 +434,8 @@ def add_settings(organization, app_name, event_name="closeEvent"):
             app_name,
         )
         for attr, widget, property in self._bind_data:
+            if not is_qt_object_alive(widget):
+                continue
             if property == "geometry":
                 settings.setValue(attr, widget.saveGeometry())
             elif property == "state":
@@ -524,9 +494,7 @@ def get_fit_geometry():
         (screen.availableGeometry() for screen in QtWidgets.QApplication.screens()),
         None,
     )
-    return QtCore.QRect(
-        geo.width() / 4, geo.height() / 4, geo.width() / 2, geo.height() / 2
-    )
+    return QtCore.QRect(geo.width() / 4, geo.height() / 4, geo.width() / 2, geo.height() / 2)
 
 
 def convert_to_round_pixmap(orig_pix):
@@ -536,9 +504,7 @@ def convert_to_round_pixmap(orig_pix):
     pix_map.fill(QtCore.Qt.transparent)
 
     painter = QtGui.QPainter(pix_map)
-    painter.setRenderHints(
-        QtGui.QPainter.Antialiasing | QtGui.QPainter.SmoothPixmapTransform
-    )
+    painter.setRenderHints(QtGui.QPainter.Antialiasing | QtGui.QPainter.SmoothPixmapTransform)
 
     path = QtGui.QPainterPath()
     path.addEllipse(0, 0, w, w)
@@ -547,13 +513,14 @@ def convert_to_round_pixmap(orig_pix):
     return pix_map
 
 
-def generate_text_pixmap(width, height, text, alignment=QtCore.Qt.AlignCenter):
+def generate_text_pixmap(width, height, text, alignment=QtCore.Qt.AlignCenter, bg_color=None):
     # Import local modules
     from dayu_widgets import dayu_theme
 
+    bg_color = bg_color or dayu_theme.background_in_color
     # draw a pixmap with text
     pix_map = QtGui.QPixmap(width, height)
-    pix_map.fill(QtGui.QColor(dayu_theme.background_in_color))
+    pix_map.fill(QtGui.QColor(bg_color))
     painter = QtGui.QPainter(pix_map)
     painter.setRenderHints(QtGui.QPainter.TextAntialiasing)
     font = painter.font()
